@@ -190,12 +190,14 @@ simpleQuery <- function(query=NULL, file=NULL,
     
         dat <- content(r, "text", encoding=encoding)
         sp <- strsplit(dat, '\n')
-        res.table <- data.frame(matrix(nrow=length(sp[[1]])-1, ncol=length(strsplit(sp[[1]][1], '\t')[[1]])))
+        res.table <- data.frame(matrix(nrow=length(sp[[1]])-1, ncol=length(strsplit(sp[[1]][1], '\t')[[1]])), stringsAsFactors = FALSE)
+        #res.table <- data.frame(matrix(nrow=length(sp[[1]])-1, ncol=length(strsplit(sp[[1]][1], '\t')[[1]])))
         colnames(res.table) <- strsplit(sp[[1]][1], '\t')[[1]]
     
         for(i in 2:length(sp[[1]])) {
             res.table[i-1,] <- strsplit(sp[[1]][i], '\t')[[1]]
         }
+        
     }, error=function(e) {
         print(e)
     })
@@ -208,7 +210,8 @@ simpleQuery <- function(query=NULL, file=NULL,
             res.table[,i] <- col.num.conv
         }
     }
-  
+    
+    
     if(querySNP) {
         res.table <- res.table[which(res.table$is_query_snp == 1), ]
     }
@@ -219,7 +222,7 @@ simpleQuery <- function(query=NULL, file=NULL,
   
     # Removing blank rows:
     res.table <- res.table[, colSums(is.na(res.table)) <= 1] 
-  
+    
     # Adding additional columns: 
     user.agent <- "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0"
     body$output <- "html"
@@ -245,7 +248,7 @@ simpleQuery <- function(query=NULL, file=NULL,
     
         if(n.col < 23) {
             while(n.col < 23) {
-                tmp.col <- data.frame(replicate(n.row, ""))
+                tmp.col <- data.frame(replicate(n.row, ""), stringsAsFactors = FALSE)
                 colnames(tmp.col) <- paste("V",n.col+1, sep="")
                 tmp.table <- cbind(tmp.table, tmp.col)
                 n.col <- dim(tmp.table)[2]
@@ -268,15 +271,14 @@ simpleQuery <- function(query=NULL, file=NULL,
     }
   
     if(!is.null(html.table)) {
-        tmp.table <- html.table[, c(5,13:14)]
+        tmp.table <- data.frame(html.table[, c(5,13:14)], stringsAsFactors = FALSE)
         tmp.table <- tmp.table[!duplicated(tmp.table), ]
         if("variant" %in% colnames(tmp.table)) {
             data.merged <- merge(res.table, tmp.table, by.x="rsID", by.y="variant")
         } else {
-            #print(head(tmp.table))
             data.merged <- merge(res.table, tmp.table, by.x="rsID", by.y="V5")
         }
-    
+        
         data.merged1 <- cbind(data.merged[["chr"]],
                           data.merged[["pos_hg38"]],
                           data.merged[["r2"]],
@@ -310,7 +312,8 @@ simpleQuery <- function(query=NULL, file=NULL,
                           data.merged[["RefSeq_distance"]],
                           data.merged[["dbSNP_functional_annotation"]],
                           data.merged[["query_snp_rsid"]])
-        data.merged <- data.frame(data.merged1, data.merged[,34:35])
+        data.merged <- data.frame(data.merged1, data.merged[,34:35], stringsAsFactors = FALSE)
+        #data.merged <- cbind(data.merged1, data.merged[,34:35])
     
         colnames(data.merged) <- c("chr", "pos_hg38", "r2", "D'", "is_query_snp", 
                                "rsID", "ref", "alt", "AFR", "AMR", 
@@ -327,6 +330,17 @@ simpleQuery <- function(query=NULL, file=NULL,
                                "Enhancer_histone_marks")
     
     }
-  
+    
+    # Make important columns to be numeric
+    data.merged[["chr"]] <- as.num(data.merged[["chr"]])
+    data.merged[["r2"]] <- as.num(data.merged[["r2"]])
+    data.merged[["D'"]] <- as.num(data.merged[["D'"]])
+    data.merged[["is_query_snp"]] <- as.num(data.merged[["is_query_snp"]])
+    data.merged[["AFR"]] <- as.num(data.merged[["AFR"]])
+    data.merged[["AMR"]] <- as.num(data.merged[["AMR"]])
+    data.merged[["ASN"]] <- as.num(data.merged[["ASN"]])
+    data.merged[["EUR"]] <- as.num(data.merged[["EUR"]])
+    
+    
     return(data.merged)
 }
\ No newline at end of file
